@@ -4,24 +4,28 @@ class NormalizedQuery {
 	var $normalizedText;
 	var $duration = 0;
 	var $count = 0;
-	var $examples;
+	var $examples = false;
 	
-	function NormalizedQuery($normalizedText) {
-		$this->normalizedText = $normalizedText;
-		$this->examples = new SlowestQueryList(1);
+	function NormalizedQuery(& $query) {
+		$this->normalizedText = $query->getNormalizedText();
+		$maxExamples = getConfig('max_number_of_examples');
+		if($maxExamples) {
+			$this->examples = new SlowestQueryList($maxExamples);
+		}
+		
+		$this->addQuery($query);
 	}
 	
 	function addQuery(& $query) {
 		$this->count ++;
 		$this->duration += $query->getDuration();
-		if($this->count == 1) {
-			$this->examples->addQuery($query);
-		} else {
-			if($this->count > 1000) {
-				$this->examples->setSize(3);
-			}
-			if((intval(rand(1, 9)) % 5) == 0) {
+		if($this->examples) {
+			if($this->count == 1) {
 				$this->examples->addQuery($query);
+			} else {
+				if(intval(rand(1, 100)) == 50) {
+					$this->examples->addQuery($query);
+				}
 			}
 		}
 	}
