@@ -8,5 +8,7 @@ require_once('query/NormalizedQueriesListener.class.php');
 
 require_once('error/ErrorListener.class.php');
 require_once('error/PrintErrorListener.class.php');
+require_once('error/GlobalErrorCountersListener.class.php');
+require_once('error/NormalizedErrorsListener.class.php');
 
 ?>
\ No newline at end of file
