@@ -3,8 +3,8 @@
 class SlowestQueriesListener extends QueryListener {
 	var $queryList;
 	
-	function SlowestQueriesListener($queriesNumber = DEFAULT_TOP_QUERIES_NUMBER) {
-		$this->queryList = new SlowestQueryList($queriesNumber);
+	function SlowestQueriesListener() {
+		$this->queryList = new SlowestQueryList(getConfig('default_top_queries_number'));
 	}
 	
 	function fireEvent(& $query) {
