@@ -15,4 +15,7 @@ require_once('reports/NormalizedQueriesMostTimeReport.class.php');
 require_once('reports/NormalizedQueriesMostFrequentReport.class.php');
 require_once('reports/NormalizedQueriesSlowestAverageReport.class.php');
 
+require_once('reports/NormalizedErrorsReport.class.php');
+require_once('reports/NormalizedErrorsMostFrequentReport.class.php');
+
 ?>
\ No newline at end of file
